=============
Bilby example
=============

Nessai is compatible with bilby via a fork of bilby. See :ref:`here<Using nessai with bilby>` for instructions for installing the required fork.

Nessai can be used like any of the other samplers in and the full range of settings are availble. The following example mirrors the :doc:`Gaussian example<gaussian-example>` but using bilby.

Code
====

.. literalinclude:: ../examples/bilby_example.py
    :language: python
